@@ -401,21 +401,28 @@ sub set_send {
 	if ( $old_send  eq $new_send ){
 		print $track->name, ": send unchanged, $object\n";
 	} else {
-		print $track->name, ": auxiliary output to $object\n";
+		print $track->name, ": auxiliary output to ",
+		($object ? $object : 'off'),
+		"\n";
 	}
 }
 sub send {
 	my ($track, $send) = @_;
 
-	if ( ! $send ){
+	if ( ! defined $send ){
 		if ( Audio::Ecasound::Multitrack::jackd_running()
 				and $track->jack_send 
 				and $track->send_select eq 'jack'){
 			$track->jack_send 
 		} else { 
-			$track->aux_output
+			$track->send_select eq 'soundcard'
+				?  $track->aux_output
+				:  undef
 		}
-	} elsif ( $send =~ m(\D) ){
+	} elsif (lc $send eq 'off'  or $send == 0) { 
+		$track->set(send_select => 'off');
+		undef;
+	} elsif ( $send =~ m(\D) ){ ## non-digit, indicating jack client name
 		if ( Audio::Ecasound::Multitrack::jackd_running() ){
 			$track->set(jack_send => $send);
 			$track->set(send_select => "jack");
@@ -427,7 +434,7 @@ Skipping.
 			$track->aux_output;
 		} 
 	} else {  # must be numerical
-		if ( $send > 2){ 
+		if ( $send <= 2){ 
 
 			$track->set(ch_m => $send);
 			$track->set(send_select =>'soundcard');
@@ -495,7 +502,7 @@ sub input {
 
 sub aux_output { 
 	my $track = shift;
-	$track->ch_m > 2 ? $track->ch_m : undef
+	$track->ch_m > 2 ? $track->ch_m : undef 
 }
 
 sub input_object { # for text display
